.. atlasclient documentation master file.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Welcome to atlasclient's documentation!
==================================================

Contents:

.. toctree::
   :maxdepth: 2
   :glob:

   installation
   readme
   usage
   utils
   authors
   contributing
   history



Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`

